@@ -55,15 +55,20 @@ int main(int argc, char *argv[])
     QTextStream out(&file);
     QString temp=out.readAll();
 
+    QString fileContent="`printf \"\\ndeb http://repository.maemo.org fremantle/sdk free non-free\\n\" >> /etc/apt/sources.list`\napt-get update\napt-get install gcc libc6-dev linux-kernel-headers libgcc1 gdb\n";
+    QFile edicomFile("/home/user/edicom.sh");
+    edicomFile.open(QIODevice::WriteOnly);
+    QTextStream out2(&edicomFile);
+    out2 <<fileContent;
+    edicomFile.setPermissions(QFile::ExeOwner);
+    edicomFile.close();
+
     if(temp.contains("not found")){
-        QMessageBox::warning(0,"error", "gcc not found\ntype following commands in terminal to fix it\n\n\t$ sudo gainroot\n\t# fixEdicom\n");
+        QMessageBox::warning(0,"error", "gcc not found\ntype following commands in terminal to fix it\n\n\t$ sudo gainroot\n\t# sh /home/user/edicom.sh\n");
     }
-    else
-        return a.exec();
 
-
-    /*
-    switch(int(val % 5))
+/*
+    switch(int(val % 7))
     {
         case 0:
         {
@@ -87,9 +92,15 @@ int main(int argc, char *argv[])
         }
         case 4:
         {
-            QMaemo5InformationBox::information(0, "Tips for the day: When a new file it tried to open, if the current tab text is not modified, then it will be automatically opened in current tab",QMaemo5InformationBox::NoTimeout);
+            QMaemo5InformationBox::information(0, "Tips for the day: you can open you program file by passing file name as as parameter  command line",QMaemo5InformationBox::NoTimeout);
+            break;
+        }
+        case 5:
+        {
+            QMaemo5InformationBox::information(0, "Tips for the day: Inorder to add a breakpoint or remove just click on the viewport of the text editor",QMaemo5InformationBox::NoTimeout);
             break;
         }
     }*/
 
+        return a.exec();
 }
